dri-devel Archive mirror
 help / color / mirror / Atom feed
From: Easwar Hariharan <eahariha@linux.microsoft.com>
To: Andy Walls <awalls@md.metrocast.net>,
	Mauro Carvalho Chehab <mchehab@kernel.org>,
	linux-media@vger.kernel.org (open list:IVTV VIDEO4LINUX DRIVER),
	linux-kernel@vger.kernel.org (open list)
Cc: Wolfram Sang <wsa+renesas@sang-engineering.com>,
	amd-gfx@lists.freedesktop.org (open list:RADEON and AMDGPU DRM
	DRIVERS), dri-devel@lists.freedesktop.org (open list:DRM DRIVERS),
	linux-kernel@vger.kernel.org (open list),
	intel-gfx@lists.freedesktop.org (open list:INTEL DRM DISPLAY FOR
	XE AND I915 DRIVERS),
	 intel-xe@lists.freedesktop.org (open list:INTEL DRM DISPLAY FOR
	XE AND I915 DRIVERS),
	 nouveau@lists.freedesktop.org (open list:DRM DRIVER FOR NVIDIA
	GEFORCE/QUADRO GPUS),
	linux-i2c@vger.kernel.org (open list:I2C SUBSYSTEM HOST DRIVERS),
	linux-media@vger.kernel.org (open list:BTTV VIDEO4LINUX DRIVER),
	linux-fbdev@vger.kernel.org (open list:FRAMEBUFFER LAYER),
	Easwar Hariharan <eahariha@linux.microsoft.com>
Subject: [PATCH v2 08/12] media: ivtv: Make I2C terminology more inclusive
Date: Fri,  3 May 2024 18:13:29 +0000	[thread overview]
Message-ID: <20240503181333.2336999-9-eahariha@linux.microsoft.com> (raw)
In-Reply-To: <20240503181333.2336999-1-eahariha@linux.microsoft.com>

I2C v7, SMBus 3.2, and I3C 1.1.1 specifications have replaced "master/slave"
with more appropriate terms. Inspired by and following on to Wolfram's
series to fix drivers/i2c/[1], fix the terminology for users of
I2C_ALGOBIT bitbanging interface, now that the approved verbiage exists
in the specification.

Compile tested, no functionality changes intended

[1]: https://lore.kernel.org/all/20240322132619.6389-1-wsa+renesas@sang-engineering.com/

Signed-off-by: Easwar Hariharan <eahariha@linux.microsoft.com>
---
 drivers/media/pci/ivtv/ivtv-i2c.c | 20 ++++++++++----------
 1 file changed, 10 insertions(+), 10 deletions(-)

diff --git a/drivers/media/pci/ivtv/ivtv-i2c.c b/drivers/media/pci/ivtv/ivtv-i2c.c
index c052c57c6dce..a22c7caa92f7 100644
--- a/drivers/media/pci/ivtv/ivtv-i2c.c
+++ b/drivers/media/pci/ivtv/ivtv-i2c.c
@@ -33,14 +33,14 @@
     Some more general comments about what we are doing:
 
     The i2c bus is a 2 wire serial bus, with clock (SCL) and data (SDA)
-    lines.  To communicate on the bus (as a master, we don't act as a slave),
+    lines.  To communicate on the bus (as a controller, we don't act as a target),
     we first initiate a start condition (ivtv_start).  We then write the
     address of the device that we want to communicate with, along with a flag
-    that indicates whether this is a read or a write.  The slave then issues
+    that indicates whether this is a read or a write.  The target then issues
     an ACK signal (ivtv_ack), which tells us that it is ready for reading /
     writing.  We then proceed with reading or writing (ivtv_read/ivtv_write),
     and finally issue a stop condition (ivtv_stop) to make the bus available
-    to other masters.
+    to other controllers.
 
     There is an additional form of transaction where a write may be
     immediately followed by a read.  In this case, there is no intervening
@@ -379,7 +379,7 @@ static int ivtv_waitsda(struct ivtv *itv, int val)
 	return 0;
 }
 
 /* Wait for the slave to issue an ACK */
 static int ivtv_ack(struct ivtv *itv)
 {
 	int ret = 0;
@@ -396,7 +396,7 @@ static int ivtv_ack(struct ivtv *itv)
 	ivtv_scldelay(itv);
 	ivtv_setscl(itv, 1);
 	if (!ivtv_waitsda(itv, 0)) {
-		IVTV_DEBUG_I2C("Slave did not ack\n");
+		IVTV_DEBUG_I2C("Target did not ack\n");
 		ret = -EREMOTEIO;
 	}
 	ivtv_setscl(itv, 0);
@@ -407,7 +407,7 @@ static int ivtv_ack(struct ivtv *itv)
 	return ret;
 }
 
 /* Write a single byte to the i2c bus and wait for the slave to ACK */
 static int ivtv_sendbyte(struct ivtv *itv, unsigned char byte)
 {
 	int i, bit;
@@ -427,7 +427,7 @@ static int ivtv_sendbyte(struct ivtv *itv, unsigned char byte)
 		}
 		ivtv_setscl(itv, 1);
 		if (!ivtv_waitscl(itv, 1)) {
-			IVTV_DEBUG_I2C("Slave not ready for bit\n");
+			IVTV_DEBUG_I2C("Target not ready for bit\n");
 			return -EREMOTEIO;
 		}
 	}
@@ -471,7 +471,7 @@ static int ivtv_readbyte(struct ivtv *itv, unsigned char *byte, int nack)
 	return 0;
 }
 
-/* Issue a start condition on the i2c bus to alert slaves to prepare for
+/* Issue a start condition on the i2c bus to alert targets to prepare for
    an address write */
 static int ivtv_start(struct ivtv *itv)
 {
@@ -534,7 +534,7 @@ static int ivtv_stop(struct ivtv *itv)
 	return 0;
 }
 
 /* Write a message to the given i2c slave.  do_stop may be 0 to prevent
    issuing the i2c stop condition (when following with a read) */
 static int ivtv_write(struct ivtv *itv, unsigned char addr, unsigned char *data, u32 len, int do_stop)
 {
@@ -558,7 +558,7 @@ static int ivtv_write(struct ivtv *itv, unsigned char addr, unsigned char *data,
 	return ret;
 }
 
 /* Read data from the given i2c slave.  A stop condition is always issued. */
 static int ivtv_read(struct ivtv *itv, unsigned char addr, unsigned char *data, u32 len)
 {
 	int retry, ret = -EREMOTEIO;
@@ -379,7 +379,7 @@ static int ivtv_waitsda(struct ivtv *itv, int val)
 }
 
-/* Wait for the slave to issue an ACK */
+/* Wait for the target to issue an ACK */
 static int ivtv_ack(struct ivtv *itv)
 {
@@ -407,7 +407,7 @@ static int ivtv_ack(struct ivtv *itv)
 }
 
-/* Write a single byte to the i2c bus and wait for the slave to ACK */
+/* Write a single byte to the i2c bus and wait for the target to ACK */
 static int ivtv_sendbyte(struct ivtv *itv, unsigned char byte)
 {
@@ -534,7 +534,7 @@ static int ivtv_stop(struct ivtv *itv)
 }
 
-/* Write a message to the given i2c slave.  do_stop may be 0 to prevent
+/* Write a message to the given i2c target.  do_stop may be 0 to prevent
    issuing the i2c stop condition (when following with a read) */
 static int ivtv_write(struct ivtv *itv, unsigned char addr, unsigned char *data, u32 len, int do_stop)
@@ -558,7 +558,7 @@ static int ivtv_write(struct ivtv *itv, unsigned char addr, unsigned char *data,
 }
 
-/* Read data from the given i2c slave.  A stop condition is always issued. */
+/* Read data from the given i2c target.  A stop condition is always issued. */
 static int ivtv_read(struct ivtv *itv, unsigned char addr, unsigned char *data, u32 len)
 {
-- 
2.34.1


  parent reply	other threads:[~2024-05-03 18:15 UTC|newest]

Thread overview: 24+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2024-05-03 18:13 [PATCH v2 00/12] Make I2C terminology more inclusive for I2C Algobit and consumers Easwar Hariharan
2024-05-03 18:13 ` [PATCH v2 01/12] drm/amdgpu, drm/radeon: Make I2C terminology more inclusive Easwar Hariharan
2024-05-07 18:16   ` Easwar Hariharan
2024-05-08 14:53     ` Alex Deucher
2024-05-08 20:12       ` Easwar Hariharan
2024-05-08 21:12         ` Alex Deucher
2024-05-03 18:13 ` [PATCH v2 02/12] drm/gma500: " Easwar Hariharan
2024-05-03 18:13 ` [PATCH v2 03/12] drm/i915: " Easwar Hariharan
2024-05-03 19:34   ` Rodrigo Vivi
2024-05-03 21:04     ` Easwar Hariharan
2024-05-03 21:14       ` Rodrigo Vivi
2024-05-06  9:06         ` Jani Nikula
2024-05-06  9:17     ` Andi Shyti
2024-05-03 18:13 ` [PATCH v2 04/12] media: au0828: " Easwar Hariharan
2024-05-03 18:13 ` [PATCH v2 05/12] media: cobalt: " Easwar Hariharan
2024-05-03 18:13 ` [PATCH v2 06/12] media: cx18: " Easwar Hariharan
2024-05-03 18:13 ` [PATCH v2 07/12] media: cx25821: " Easwar Hariharan
2024-05-03 18:13 ` Easwar Hariharan [this message]
2024-05-03 18:13 ` [PATCH v2 09/12] media: cx23885: " Easwar Hariharan
2024-05-03 18:13 ` [PATCH v2 10/12] sfc: falcon: " Easwar Hariharan
2024-05-03 18:13 ` [PATCH v2 11/12] fbdev/smscufx: " Easwar Hariharan
2024-05-06  9:21   ` Thomas Zimmermann
2024-05-03 18:13 ` [PATCH v2 12/12] fbdev/viafb: " Easwar Hariharan
2024-05-06  9:22   ` Thomas Zimmermann

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20240503181333.2336999-9-eahariha@linux.microsoft.com \
    --to=eahariha@linux.microsoft.com \
    --cc=amd-gfx@lists.freedesktop.org \
    --cc=awalls@md.metrocast.net \
    --cc=dri-devel@lists.freedesktop.org \
    --cc=intel-gfx@lists.freedesktop.org \
    --cc=intel-xe@lists.freedesktop.org \
    --cc=linux-fbdev@vger.kernel.org \
    --cc=linux-i2c@vger.kernel.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-media@vger.kernel.org \
    --cc=mchehab@kernel.org \
    --cc=nouveau@lists.freedesktop.org \
    --cc=wsa+renesas@sang-engineering.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).